
<template>
  <view-grid
    ref="grid"
    :columns="columns"
    :detail="detail"
    :editFormFields="editFormFields"
    :editFormOptions="editFormOptions"
    :searchFormFields="searchFormFields"
    :searchFormOptions="searchFormOptions"
    :table="table"
    :extend="extend"
  >
  </view-grid>
</template>
      <script>
import extend from "@/extension/basic/roadwayInfo.js";
import { ref, defineComponent } from "vue";
export default defineComponent({
  setup() {
    const table = ref({
      key: "id",
      footer: "Foots",
      cnName: "巷道信息",
      name: "roadwayInfo",
      url: "/roadwayInfo/",
      sortName: "id",
    });
    const editFormFields = ref({
      roadwayNo: "",
      areaId: "",
      enalbeStatus: "",
      deviceNo: "",
      inStationCode: "",
      inSCStationCode: "",
      outStationCode: "",
      outSCStationCode: "",
    });
    const editFormOptions = ref([
      [
      {title: "区域主键",field: "areaId",type: "select",dataKey: "areainfo",data: [],},
        {
          title: "巷道编号",
          required: true,
          field: "roadwayNo",
          type: "string",
        },
        {
          title: "设备编号",
          required: true,
          field: "deviceNo",
          type: "string",
        },
        {
          title: "禁用状态",
          required: true,
          field: "enalbeStatus",
          type: "select",
          dataKey: "enableStatusEnum",
          data: [],
       },
      ],
      [
        {
          title: "入库站台编号",
          field: "inStationCode",
          type: "string",
        },
        {
          title: "堆垛机入库站台编号",
          field: "inSCStationCode",
          type: "string",
        },
        {
          title: "出库站台编号",
          field: "outStationCode",
          type: "string",
        },
        {
          title: "堆垛机出库站台编号",
          field: "outSCStationCode",
          type: "string",
        },
      ],
    ]);
    const searchFormFields = ref({
      roadwayNo: "",
      areaId: "",
      enableStatus: "",
      deviceNo: "",
      inStationCode: "",
      inSCStationCode: "",
      outStationCode: "",
      outSCStationCode: "",
    });
    const searchFormOptions = ref([
      [
        { title: "巷道编号", field: "roadwayNo", type: "like" },
        {title: "区域主键",field: "areaId",type: "select",dataKey: "areainfo",data: [],},
        { title: "禁用状态", field: "enableStatus",type: "select",dataKey: "enableStatusEnum",data: [],},
      ],
      [
        { title: "入库站台编号", field: "inStationCode", type: "like" },
        { title: "堆垛机入库站台编号", field: "inSCStationCode", type: "like" },
        { title: "设备编号", field: "deviceNo", type: "like" },
      ],
      [
        { title: "出库站台编号", field: "outStationCode", type: "like" },
        { title: "堆垛机出库站台编号",field: "outSCStationCode",type: "like",},
      ]
    ]);
    const columns = ref([
      {
        field: "id",
        title: "Id",
        type: "int",
        width: 90,
        hidden: true,
        readonly: true,
        require: true,
        align: "left",
      },
      {
        field: "roadwayNo",
        title: "巷道编号",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "areaId",
        title: "区域主键",
        type: "int",
        width: 150,
        align: "left",
        bind:{ key: "areainfo", data: [] },
      },
      {
        field: "enableStatus",
        title: "禁用状态",
        type: "select",
        width: 150,
        align: "left",
        bind: { key: "enableStatusEnum", data: [] },
      },
      {
        field: "deviceNo",
        title: "设备编号",
        type: "decimal",
        width: 90,
        align: "left",
      },
      {
        field: "inStationCode",
        title: "入库站台编号",
        type: "string",
        width: 120,
        align: "left",
      },
      {
        field: "inSCStationCode",
        title: "堆垛机入库站台编号",
        type: "string",
        width: 150,
        align: "left",
      },
      {
        field: "outStationCode",
        title: "出库站台编号",
        type: "decimal",
        width: 120,
        align: "left",
      },
      {
        field: "outSCStationCode",
        title: "堆垛机出库站台编号",
        type: "string",
        width: 150,
        align: "left",
      },
      {
        field: "creater",
        title: "创建人",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "createDate",
        title: "创建时间",
        type: "datetime",
        width: 160,
        align: "left",
      },
      {
        field: "modifier",
        title: "修改人",
        type: "string",
        width: 100,
        align: "left",
      },
      {
        field: "modifyDate",
        title: "修改时间",
        type: "datetime",
        width: 160,
        align: "left",
      },
      {
        field: "remark",
        title: "备注",
        type: "string",
        width: 100,
        align: "left",
      },
    ]);
    const detail = ref({
      cnName: "#detailCnName",
      table: "",
      columns: [],
      sortName: "",
    });
    return {
      table,
      extend,
      editFormFields,
      editFormOptions,
      searchFormFields,
      searchFormOptions,
      columns,
      detail,
    };
  },
});
</script>
      